==> openrqm-1.0.2.tar.gz: doc/RQMDocument.md <==
# openrqm.model.RQMDocument

## Load the model package
```dart
import 'package:openrqm/api.dart';
```

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **int** |  | [optional] [default to null]
**workspaceId** | **int** |  | [optional] [default to null]
**internalIdentifier** | **int** |  | [optional] [default to null]
**externalIdentifier** | **int** |  | [optional] [default to null]
**name** | **String** |  | [optional] [default to null]
**shortName** | **String** |  | [optional] [default to null]
**description** | **String** |  | [optional] [default to null]
**confidentiality** | **String** |  | [optional] [default to null]
**authorId** | **int** |  | [optional] [default to null]
**languageId** | **int** |  | [optional] [default to null]
**approverId** | **int** |  | [optional] [default to null]
**reviewerText** | **String** |  | [optional] [default to null]
**lastModifiedById** | **int** |  | [optional] [default to null]
**lastModifiedOn** | [**DateTime**](DateTime.md) |  | [optional] [default to null]
**baselineMajor** | **int** |  | [optional] [default to null]
**baselineMinor** | **int** |  | [optional] [default to null]
**baselineReview** | **int** |  | [optional] [default to null]
**previousBaselineId** | **int** |  | [optional] [default to null]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

==> openrqm-1.0.24.tar.gz: doc/RQMDocument.md <==
# openrqm.model.RQMDocument

## Load the model package
```dart
import 'package:openrqm/api.dart';
```

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **int** |  | [optional] [default to null]
**workspaceId** | **int** |  | [optional] [default to null]
**internalIdentifier** | **int** |  | [optional] [default to null]
**externalIdentifier** | **String** |  | [optional] [default to null]
**name** | **String** |  | [optional] [default to null]
**shortName** | **String** |  | [optional] [default to null]
**description** | **String** |  | [optional] [default to null]
**confidentiality** | **String** |  | [optional] [default to null]
**authorId** | **int** |  | [optional] [default to null]
**languageId** | **int** |  | [optional] [default to null]
**approverId** | **int** |  | [optional] [default to null]
**reviewerText** | **String** |  | [optional] [default to null]
**lastModifiedById** | **int** |  | [optional] [default to null]
**lastModifiedOn** | [**DateTime**](DateTime.md) |  | [optional] [default to null]
**baselineMajor** | **int** |  | [optional] [default to null]
**baselineMinor** | **int** |  | [optional] [default to null]
**baselineReview** | **int** |  | [optional] [default to null]
**previousBaselineId** | **int** |  | [optional] [default to null]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)
